==> kdecoration-5.27.10.tgz: lib/cmake/KDecoration2/KDecoration2Targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDecoration2::KDecoration2Private" for configuration "Release"
set_property(TARGET KDecoration2::KDecoration2Private APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDecoration2::KDecoration2Private PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libkdecorations2private.so.0.1"
  IMPORTED_SONAME_RELEASE "libkdecorations2private.so.0.1"
  )

list(APPEND _cmake_import_check_targets KDecoration2::KDecoration2Private )
list(APPEND _cmake_import_check_files_for_KDecoration2::KDecoration2Private "${_IMPORT_PREFIX}/lib/libkdecorations2private.so.0.1" )

# Import target "KDecoration2::KDecoration" for configuration "Release"
set_property(TARGET KDecoration2::KDecoration APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDecoration2::KDecoration PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDecoration2::KDecoration2Private;KF5::I18n;KF5::CoreAddons"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libkdecorations2.so.0.4"
  IMPORTED_SONAME_RELEASE "libkdecorations2.so.0.4"
  )

list(APPEND _cmake_import_check_targets KDecoration2::KDecoration )
list(APPEND _cmake_import_check_files_for_KDecoration2::KDecoration "${_IMPORT_PREFIX}/lib/libkdecorations2.so.0.4" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> kdecoration-6.1.4.tgz: lib/cmake/KDecoration2/KDecoration2Targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDecoration2::KDecoration2Private" for configuration "Release"
set_property(TARGET KDecoration2::KDecoration2Private APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDecoration2::KDecoration2Private PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libkdecorations2private.so.1.0"
  IMPORTED_SONAME_RELEASE "libkdecorations2private.so.1.0"
  )

list(APPEND _cmake_import_check_targets KDecoration2::KDecoration2Private )
list(APPEND _cmake_import_check_files_for_KDecoration2::KDecoration2Private "${_IMPORT_PREFIX}/lib/libkdecorations2private.so.1.0" )

# Import target "KDecoration2::KDecoration" for configuration "Release"
set_property(TARGET KDecoration2::KDecoration APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KDecoration2::KDecoration PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KDecoration2::KDecoration2Private;KF6::I18n"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libkdecorations2.so.1.0"
  IMPORTED_SONAME_RELEASE "libkdecorations2.so.1.0"
  )

list(APPEND _cmake_import_check_targets KDecoration2::KDecoration )
list(APPEND _cmake_import_check_files_for_KDecoration2::KDecoration "${_IMPORT_PREFIX}/lib/libkdecorations2.so.1.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
